@@ -44,10 +44,15 @@ def speak(widget, LangPickerButton, LangSelectorObj, AmpPickerButton, PitchPicke
  global isNowFullScreen
  
  textresult = textresult.replace("\"","").replace("'","").replace("\\","")
- espeakcmd = "espeak -v " + currentlang + " -a " + currentAmp + " -p " + currentPitch + " -s " + currentSpeed + " -g " + currentWordGap + " \"" + textresult + "\"" 
+ espeakcmd = "espeak -v " + currentlang + " -a " + currentAmp + " -p " + currentPitch + " -s " + currentSpeed + " -g " + currentWordGap + " \"" + textresult + "\" &" 
  print espeakcmd
  os.system(espeakcmd)
 
+# The method kills all the espeak processes so that it stops all current speaking
+def stop(widget):
+ espeakcmd = "pkill espeak &" 
+ os.system(espeakcmd)
+ 
 # The method that pastes text to the TextView control from the clipboard.
 def pasteText(widget, TextArea, LangPickerButton, LangSelectorObj, AmpPickerButton, PitchPickerButton, SpeedPickerButton, WordGapPickerButton):
  clip = gtk.Clipboard()
@@ -245,6 +250,7 @@ def main():
 
 # Define the vibile buttons of the program.
  speakButton = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL, _("eSpeakGUI_SpeakButtonLabel"))
+ stopButton = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL, _("eSpeakGUI_StopButtonLabel"))
  pasteTextButton = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL, _("eSpeakGUI_PasteTextButtonLabel"))
  clearTextButton = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL, _("eSpeakGUI_ClearTextButtonLabel"))
  saveAsWavButton = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL, _("eSpeakGUI_SaveAsWavButtonLabel"))
@@ -345,6 +351,7 @@ def main():
  vbox2.pack_start(pasteTextButton, True, True, 0)
  vbox2.pack_start(clearTextButton, True, True, 0)
  vbox2.pack_start(saveAsWavButton, True, True, 0)
+ vbox2.pack_start(stopButton, True, True, 0)
  vbox2.pack_start(speakButton, True, True, 0)
  hbox2.pack_start(vbox2, False, False, 0) 
  
@@ -356,6 +363,7 @@ def main():
 # Define the button events and their handlers.
  
  speakButton.connect("clicked", speak, lang_picker_button, LangSelectorObj, amp_picker_button, pitch_picker_button, speed_picker_button, wordgap_picker_button)
+ stopButton.connect("clicked", stop)
  pasteTextButton.connect("clicked", pasteText, textview, lang_picker_button, LangSelectorObj, amp_picker_button, pitch_picker_button, speed_picker_button, wordgap_picker_button)
  clearTextButton.connect("clicked", clearText, textview, lang_picker_button, LangSelectorObj, amp_picker_button, pitch_picker_button, speed_picker_button, wordgap_picker_button) 
  saveAsWavButton.connect("clicked", saveAsWav, textview, lang_picker_button, LangSelectorObj, amp_picker_button, pitch_picker_button, speed_picker_button, wordgap_picker_button) 
